# Changelog

Version numbers follow the [semantic version](https://semver.org/) (`<major>.<minor>.<patch>`) format.

Changes for the upcoming release can be found (and will be added on merging feature branches) in the next section.

Changes from previous releases are listed below.

## Upcoming Release

*No changes yet.*

## 0.2.0 (2024-06-10)

- Relax the torch version requirement to `torch>=2.0` instead of `torch==2.2.0` _(see #1 and #2)_

## 0.1.0 (2024-04-26)

- Initial release
